@@ -44,11 +44,14 @@
 #include <glib/gstdio.h>
 #include <glib-object.h>
 #include <gtk/gtk.h>
+#include <handy.h>
 
 #ifdef HAVE_EXEMPI
 #include <exempi/xmp.h>
 #endif
 
+#define is_rtl (gtk_widget_get_default_direction () == GTK_TEXT_DIR_RTL)
+
 static void eog_application_load_accelerators (void);
 static void eog_application_save_accelerators (void);
 
@@ -194,7 +197,7 @@ eog_application_init_app_menu (EogApplication *application)
 static void
 eog_application_init_accelerators (GtkApplication *application)
 {
-	/* Based on a simular construct in Evince (src/ev-application.c).
+	/* Based on a similar construct in Evince (src/ev-application.c).
 	 * Setting multiple accelerators at once for an action
 	 * is not very straight forward in a static way.
 	 *
@@ -209,11 +212,10 @@ eog_application_init_accelerators (GtkApplication *application)
 		"win.close-all",	"<Ctrl>q", NULL,
 		"win.print",		"<Ctrl>p", NULL,
 		"win.properties",	"<Alt>Return", NULL,
+		"win.show-remote",	"<Ctrl><Shift>p", NULL,
 		"win.set-wallpaper",	"<Ctrl>F8", NULL,
 		"win.manual",		"F1", NULL,
 
-		"win.go-previous",	"BackSpace", NULL,
-		/* "win.go-next",	NULL,*/
 		"win.go-first",		"<Alt>Home", "Home", NULL,
 		"win.go-last",		"<Alt>End", "End", NULL,
 		"win.go-random",	"<Ctrl>m", NULL,
@@ -225,9 +227,14 @@ eog_application_init_accelerators (GtkApplication *application)
 		"win.undo",		"<Ctrl>z", NULL,
 		"win.zoom-in",		"<Ctrl>equal", "<Ctrl>KP_Add",
 					"<Ctrl>plus", NULL,
+		"win.zoom-in-smooth",		"equal", "KP_Add",
+					"plus", NULL,
 		"win.zoom-out",		"<Ctrl>minus",
 					"<Ctrl>KP_Subtract", NULL,
-		"win.zoom-normal",	"<Ctrl>0", "<Ctrl>KP_0", NULL,
+		"win.zoom-out-smooth",		"minus",
+					"KP_Subtract", NULL,
+		"win.zoom-normal",	"<Ctrl>0", "<Ctrl>KP_0",
+					"1", "KP_1", NULL,
 
 		"win.view-gallery",	"<Ctrl>F9", NULL,
 		"win.view-sidebar",	"F9", NULL,
@@ -246,6 +253,25 @@ eog_application_init_accelerators (GtkApplication *application)
 		gtk_application_set_accels_for_action (GTK_APPLICATION (application),
 						       it[0], &it[1]);
 	}
+
+	static const gchar * const accels_left[] = {
+		"Left", "<Alt>Left", NULL
+	};
+	static const gchar * const accels_right[] = {
+		"Right", "<Alt>Right", NULL
+	};
+
+	if (is_rtl) {
+		gtk_application_set_accels_for_action (GTK_APPLICATION (application),
+					       "win.go-previous", accels_right);
+		gtk_application_set_accels_for_action (GTK_APPLICATION (application),
+					       "win.go-next", accels_left);
+	} else {
+		gtk_application_set_accels_for_action (GTK_APPLICATION (application),
+					       "win.go-previous", accels_left);
+		gtk_application_set_accels_for_action (GTK_APPLICATION (application),
+					       "win.go-next", accels_right);
+	}
 }
 
 static void
@@ -272,12 +298,13 @@ eog_application_startup (GApplication *application)
 	EogApplication *app = EOG_APPLICATION (application);
 	GError *error = NULL;
 	GFile *css_file;
-	GtkSettings *settings;
 	GtkCssProvider *provider;
+  HdyStyleManager *style_manager;
 
 	g_application_set_resource_base_path (application, "/org/gnome/eog");
 	G_APPLICATION_CLASS (eog_application_parent_class)->startup (application);
 
+  hdy_init ();
 #ifdef HAVE_EXEMPI
 	xmp_init();
 #endif
@@ -309,10 +336,9 @@ eog_application_startup (GApplication *application)
 	gtk_window_set_default_icon_name ("eog");
 	g_set_application_name (_("Image Viewer"));
 
-	settings = gtk_settings_get_default ();
-	g_object_set (G_OBJECT (settings),
-	              "gtk-application-prefer-dark-theme", TRUE,
-	              NULL);
+	style_manager = hdy_style_manager_get_default ();
+	hdy_style_manager_set_color_scheme (style_manager,
+	                                    HDY_COLOR_SCHEME_PREFER_DARK);
 
 	eog_application_init_app_menu (app);
 	eog_application_init_accelerators (GTK_APPLICATION (app));
