@@ -34,6 +34,7 @@
 
 #define EOG_CONF_DESKTOP_WALLPAPER_SCHEMA	"org.gnome.desktop.background"
 #define EOG_CONF_DESKTOP_WALLPAPER		"picture-uri"
+#define EOG_CONF_DESKTOP_WALLPAPER_DARK		"picture-uri-dark"
 
 #define EOG_CONF_DESKTOP_LOCKDOWN_SCHEMA	"org.gnome.desktop.lockdown"
 #define EOG_CONF_DESKTOP_CAN_PRINT		"disable-printing"
@@ -63,7 +64,6 @@
 #define EOG_CONF_UI_DISABLE_CLOSE_CONFIRMATION  "disable-close-confirmation"
 #define EOG_CONF_UI_DISABLE_TRASH_CONFIRMATION	"disable-trash-confirmation"
 #define EOG_CONF_UI_FILECHOOSER_XDG_FALLBACK	"filechooser-xdg-fallback"
-#define EOG_CONF_UI_PROPSDIALOG_NETBOOK_MODE	"propsdialog-netbook-mode"
 
 #define EOG_CONF_PLUGINS_ACTIVE_PLUGINS         "active-plugins"
 
